@@ -24,7 +24,9 @@ STATIC_EXT_TO_CONTENT_TYPE = {
     '.json': 'application/json',
     '.markdown': 'text/markdown; charset=utf-8',
     '.md': 'text/markdown; charset=utf-8',
+    '.mds': 'text/plain; charset=utf-8',
     '.png': 'image/png',
+    '.smd': 'text/plain; charset=utf-8',
     '.svg': 'image/svg+xml',
     '.tif': 'image/tiff',
     '.tiff': 'image/tiff',
@@ -89,7 +91,6 @@ MARKDOWN_UP_HTML = chisel.StaticRequest(
         <meta charset="UTF-8">
         <meta name="viewport" content="width=device-width, initial-scale=1">
         <link rel="stylesheet" href="https://craigahobbs.github.io/markdown-up/markdown-model.css">
-        <link rel="stylesheet" href="https://craigahobbs.github.io/markdown-up/schema-markdown-doc.css">
         <link rel="stylesheet" href="https://craigahobbs.github.io/markdown-up/app.css">
     </head>
     <body>
